@@ -255,11 +255,19 @@ impl<'a, S: Read + 'a, T: FromStream<Context = ()> + 'a> de::ArrayAccess<T> for
         let mut i = 0;
         let len = buffer.len();
         while i < len {
-            if let Some(b) = de::SeqAccess::next_element(self, ()).await? {
-                buffer[i] = b;
-                i += 1;
-            } else {
-                break;
+            match de::SeqAccess::next_element(self, ()).await {
+                Ok(Some(b)) => {
+                    buffer[i] = b;
+                    i += 1;
+                }
+                Ok(None) => break,
+                Err(cause) => {
+                    let message = match self.decoder.contents(SNIPPET_LEN) {
+                        Ok(snippet) => format!("array decode error: {} at {}...", cause, snippet),
+                        Err(_) => format!("array decode error: {}", cause),
+                    };
+                    return Err(de::Error::custom(message));
+                }
             }
         }
 
@@ -387,7 +395,7 @@ impl<S: Read> Decoder<S> {
     async fn decode_number<V: Visitor>(&mut self, visitor: V) -> Result<V::Value, Error> {
         let mut i = 0;
         loop {
-            if self.buffer[i] == DECIMAL[0] {
+            if self.buffer[i] == DECIMAL[0] || self.buffer[i] == E[0] {
                 return de::Decoder::decode_f64(self, visitor).await;
             } else if !self.numeric.contains(&self.buffer[i]) {
                 return de::Decoder::decode_i64(self, visitor).await;
